<?php

/********************************************************************************************************************************
*
*  Forum team online (/inc/plugins/forumteamonline.php)
*  Author: Krzysztof "Supryk" Supryczyński
*  Copyright: © 2013 - 2021 @ Krzysztof "Supryk" Supryczyński @ All rights reserved
*  
*  Website: http://supryk.eu/
*  Description: Show forum team online online in sidebox.
*
********************************************************************************************************************************/
/********************************************************************************************************************************
*
* This file is part of "Forum team online" plugin for MyBB.
* Copyright © 2013 - 2021 @ Krzysztof "Supryk" Supryczyński @ All rights reserved
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU Lesser General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
*
********************************************************************************************************************************/

if(!defined("IN_MYBB"))
{
	die("Direct initialization of this file is not allowed.<br /><br />Please make sure IN_MYBB is defined.");
}

$plugins->add_hook("admin_config_settings_manage", "forumteamonline_admin_lang_load");
$plugins->add_hook("admin_config_settings_change", "forumteamonline_admin_lang_load");
$plugins->add_hook("admin_config_settings_start", "forumteamonline_admin_lang_load");
$plugins->add_hook("admin_style_templates_set", "forumteamonline_admin_lang_load");
$plugins->add_hook("index_end", "forumteamonline_index_end");
$plugins->add_hook("portal_end", "forumteamonline_portal_end");
$plugins->add_hook("global_start", "forumteamonline_global_start");
$plugins->add_hook("pre_output_page", "forumteamonline_pre_output_page");

function forumteamonline_info()
{
    global $lang;
    $lang->load("config_forumteamonline");
	
	$lang->forumteamonline_desc = "<form action=\"https://www.paypal.com/donate\" method=\"post\" target=\"_top\" style=\"float:right;\">
<input type=\"hidden\" name=\"hosted_button_id\" value=\"8YTUDFQN6XAGN\" />
<input type=\"image\" src=\"https://www.paypalobjects.com/en_US/i/btn/btn_donate_LG.gif\" border=\"0\" name=\"submit\" title=\"PayPal - The safer, easier way to pay online!\" alt=\"Donate with PayPal button\" />
<img alt=\"\" border=\"0\" src=\"https://www.paypal.com/en_PL/i/scr/pixel.gif\" width=\"1\" height=\"1\" />
</form>".$lang->forumteamonline_desc;
	
	$information = array(
		"name"					=> $lang->forumteamonline_name,
		"description"			=> $lang->forumteamonline_desc,
		"website"				=> "http://supryk.eu/",
		"author"				=> "Krzysztof \"Supryk\" Supryczyński",
		"authorsite"			=> "http://supryk.eu/",
		"version"				=> "2.5",
		"compatibility"			=> "18*",
		"codename"				=> "forumteamonline",
	);
	
	return $information;
}

function forumteamonline_is_installed()
{
    global $db;
	
	$num_rows = $db->num_rows($db->simple_select("settinggroups", "*", "name = \"forumteamonline\""));
	
	return $num_rows;
}

function forumteamonline_install()
{
	global $db, $lang, $mybb;
	$lang->load("config_forumteamonline");
	
	$max_disporder = $db->fetch_field($db->simple_select("settinggroups", "MAX(disporder) AS max_disporder"), "max_disporder");
	
	$settinggroups = array(
	//	"gid"					=> "",
		"name" 			=> "forumteamonline", 
		"title" 				=> $db->escape_string($lang->setting_group_forumteamonline),
		"description"	=> $db->escape_string($lang->setting_group_forumteamonline_desc),
		"disporder" 		=> $max_disporder + 1,
		"isdefault"		=> "0",
	);
	$gid = $db->insert_query("settinggroups", $settinggroups);
	
	$settings = array();
	
	$settings[] = array(
	//	"sid"					=> "",
		"name"			=> "forumteamonline_onoff",
		"title"				=> $db->escape_string($lang->setting_forumteamonline_onoff),
		"description"	=> $db->escape_string($lang->setting_forumteamonline_onoff_desc),
		"optionscode"	=> "onoff",
		"value"				=> "1",
		"disporder"		=> "1",
		"gid"					=> $gid,
		"isdefault"			=> "0",
	);
	
	$settings[] = array(
	//	"sid"					=> "",
		"name"			=> "forumteamonline_portal_onoff",
		"title"				=> $db->escape_string($lang->setting_forumteamonline_portal_onoff),
		"description"	=> $db->escape_string($lang->setting_forumteamonline_portal_onoff_desc),
		"optionscode"	=> "onoff",
		"value"				=> "1",
		"disporder"		=> "2",
		"gid"					=> $gid,
		"isdefault"			=> "0",
	);
	
	$settings[] = array(
	//	"sid"					=> "",
		"name"			=> "forumteamonline_index_onoff",
		"title"				=> $db->escape_string($lang->setting_forumteamonline_index_onoff),
		"description"	=> $db->escape_string($lang->setting_forumteamonline_index_onoff_desc),
		"optionscode"	=> "onoff",
		"value"				=> "1",
		"disporder"		=> "3",
		"gid"					=> $gid,
		"isdefault"			=> "0",
	);
	
	$settings[] = array(
	//	"sid"					=> "",
		"name"			=> "forumteamonline_avatar_onoff",
		"title"				=> $db->escape_string($lang->setting_forumteamonline_avatar_onoff),
		"description"	=> $db->escape_string($lang->setting_forumteamonline_avatar_onoff_desc),
		"optionscode"	=> "onoff",
		"value"				=> "1",
		"disporder"		=> "4",
		"gid"					=> $gid,
		"isdefault"			=> "0",
	);
	
	$settings[] = array(
	//	"sid"					=> "",
		"name"			=> "forumteamonline_avatar_width_height",
		"title"				=> $db->escape_string($lang->setting_forumteamonline_avatar_width_height),
		"description"	=> $db->escape_string($lang->setting_forumteamonline_avatar_width_height_desc),
		"optionscode"	=> "text",
		"value"				=> "32x32",
		"disporder"		=> "5",
		"gid"					=> $gid,
		"isdefault"			=> "0",
	);
	
	$settings[] = array(
	//	"sid"					=> "",
		"name"			=> "forumteamonline_members_limit",
		"title"				=> $db->escape_string($lang->setting_forumteamonline_members_limit),
		"description"	=> $db->escape_string($lang->setting_forumteamonline_members_limit_desc),
		"optionscode"	=> "numeric",
		"value"				=> "10",
		"disporder"		=> "6",
		"gid"					=> $gid,
		"isdefault"			=> "0",
	);
	
	$options = "select\n0=".$db->escape_string($lang->setting_forumteamonline_sort_by_uid_asc_usergroup_asc)."\n";
    $options .= "1=".$db->escape_string($lang->setting_forumteamonline_sort_by_uid_asc)."\n";
    $options .= "2=".$db->escape_string($lang->setting_forumteamonline_sort_by_usergroup_asc)."\n";
    $options .= "3=".$db->escape_string($lang->setting_forumteamonline_sort_by_username_asc)."\n";
	$options .= "4=".$db->escape_string($lang->setting_forumteamonline_sort_by_disporder_asc)."\n";
    $options .= "5=".$db->escape_string($lang->setting_forumteamonline_sort_by_uid_desc)."\n";
    $options .= "6=".$db->escape_string($lang->setting_forumteamonline_sort_by_usergroup_desc)."\n";
    $options .= "7=".$db->escape_string($lang->setting_forumteamonline_sort_by_username_desc)."\n";
	$options .= "8=".$db->escape_string($lang->setting_forumteamonline_sort_by_disporder_desc)."\n";
	
	$settings[] = array(
	//	"sid"					=> "",
		"name"			=> "forumteamonline_sort_by",
		"title"				=> $db->escape_string($lang->setting_forumteamonline_sort_by),
		"description"	=> $db->escape_string($lang->setting_forumteamonline_sort_by_desc),
		"optionscode"	=> $options,
		"value"				=> "0",
		"disporder"		=> "7",
		"gid"					=> $gid,
		"isdefault"			=> "0",
	);
	
	$settings[] = array(
	//	"sid"					=> "",
		"name"			=> "forumteamonline_stats_onoff",
		"title"				=> $db->escape_string($lang->setting_forumteamonline_stats_onoff),
		"description"	=> $db->escape_string($lang->setting_forumteamonline_stats_onoff_desc),
		"optionscode"	=> "onoff",
		"value"				=> "1",
		"disporder"		=> "8",
		"gid"					=> $gid,
		"isdefault"			=> "0",
	);
	
	$db->insert_query_multiple("settings", $settings);
	
	rebuild_settings();
	
	$templategroup = array(
	//	"gid"			  		=> "",
        "prefix"       		=> "forumteamonline",
        "title"            		=> $db->escape_string("<lang:forumteamonline_templates>"),
    );
	
    $db->insert_query("templategroups", $templategroup);
	
	$templates = array();
		
	$templates[] = array(
	//	"tid" 					=> "",
		"title" 				=> "forumteamonline",
		"template" 		=> $db->escape_string('<table border="0" cellspacing="{$theme[\'borderwidth\']}" cellpadding="{$theme[\'tablespace\']}" class="tborder">
<tr>
<td class="thead">
<strong>{$lang->forumteamonline_forumteamonline}</strong>
</td>
</tr>
{$users[\'row\']}
{$users[\'stats\']}
</table>
<br/>'),
		"sid" 				=> "-2",
		"version" 				=> "2.4",
		"status" 				=> "",
		"dateline" 				=> TIME_NOW,
	);
	
	$templates[] = array(
	//	"tid" 					=> "",
		"title" 				=> "forumteamonline_row",
		"template" 		=> $db->escape_string('<tr><td class="trow1">
{$user[\'avatar\']}
{$user[\'profilelink\']}{$user[\'invisible\']}<br/>
{$user[\'usertitle\']}
</td></tr>'),
		"sid" 				=> "-2",
		"version" 				=> "2.4",
		"status" 				=> "",
		"dateline" 				=> TIME_NOW,
	);
	
	$templates[] = array(
	//	"tid" 					=> "",
		"title" 				=> "forumteamonline_row_avatar",
		"template" 		=> $db->escape_string('<img src="{$useravatar[\'image\']}" alt="" style="float: left;margin-right: 5px;" {$useravatar[\'width_height\']}/>'),
		"sid" 				=> "-2",
		"version" 				=> "2.4",
		"status" 				=> "",
		"dateline" 				=> TIME_NOW,
	);
	
	$templates[] = array(
	//	"tid" 					=> "",
		"title" 				=> "forumteamonline_row_noone",
		"template" 		=> $db->escape_string('<tr><td class="trow1">
<span>{$lang->forumteamonline_noone}</span>
</td></tr>'),
		"sid" 				=> "-2",
		"version" 				=> "2.4",
		"status" 				=> "",
		"dateline" 				=> TIME_NOW,
	);
	
	$templates[] = array(
	//	"tid" 					=> "",
		"title" 				=> "forumteamonline_row_novisible",
		"template" 		=> $db->escape_string('<tr><td class="trow1">
<span>{$lang->forumteamonline_novisible}</span>
</td></tr>'),
		"sid" 				=> "-2",
		"version" 				=> "2.4",
		"status" 				=> "",
		"dateline" 				=> TIME_NOW,
	);
	
	$templates[] = array(
	//	"tid" 					=> "",
		"title" 				=> "forumteamonline_row_stats",
		"template" 		=> $db->escape_string('<tr><td class="trow1"><span>
{$lang->forumteamonline_stats}<br />
{$lang->forumteamonline_online} {$users[\'online\']}<br />
{$lang->forumteamonline_invisible} {$users[\'invisible\']}
</span></td></tr>'),
		"sid" 				=> "-2",
		"version" 				=> "2.4",
		"status" 				=> "",
		"dateline" 				=> TIME_NOW,
	);

	$db->insert_query_multiple("templates", $templates);
}

function forumteamonline_uninstall()
{
    global $db;
	
	$db->delete_query("settinggroups", "name = \"forumteamonline\"");
	$db->delete_query("settings", "name LIKE \"forumteamonline%\"");
	rebuild_settings();
	$db->delete_query("templategroups", "prefix = \"forumteamonline\"");
	$db->delete_query("templates", "title LIKE \"forumteamonline%\"");
}

function forumteamonline_admin_lang_load()
{
    global $lang;
    $lang->load("config_forumteamonline");
} 

function forumteamonline_index_end()
{
	global $db, $cache, $lang, $mybb, $templates, $theme, $forumteamonline;
	$lang->load("forumteamonline");
		
	if($mybb->settings['forumteamonline_onoff'] != "1")
	{
		return;
	}
	
	if($mybb->settings['forumteamonline_index_onoff'] != "1")
	{
		return;
	}
	
	if($mybb->usergroup['canviewonline'] != "1")
	{
		return;
	}
	
	$timesearch = TIME_NOW - $mybb->settings['wolcutoff'];
	
	switch($mybb->settings['forumteamonline_sort_by'])
	{
		case 0:
			$sortby = "u.uid ASC, u.usergroup ASC";
		break;
		case 1:
			$sortby = "u.uid ASC";
		break;
		case 2:
			$sortby = "u.usergroup ASC";
		break;
		case 3:
			$sortby = "u.username ASC";
		break;
		case 4:
			$sortby = "g.disporder ASC";
		break;
		case 5:
			$sortby = "u.uid DESC";
		break;
		case 6:
			$sortby = "u.usergroup DESC";
		break;
		case 7:
			$sortby = "u.username DESC";
		break;
		case 8:
			$sortby = "g.disporder DESC";
		break;
	}
	
	if($mybb->settings['forumteamonline_members_limit'] <= "0")
	{
		$mybb->settings['forumteamonline_members_limit'] = "10";
	}
	
/*	$usertitles = $cache->read('usertitles');
	$usertitles_cache = array();
	foreach($usertitles as $usertitle)
	{
		$usertitles_cache[$usertitle['posts']] = $usertitle;
	}*/
	
	$query = $db->query("SELECT s.uid, u.username, u.usergroup, u.displaygroup, u.uid, u.avatar, u.avatardimensions, u.invisible, u.usertitle as userowntitle, u.postnum, g.usertitle, g.showforumteam, g.disporder
		FROM ".TABLE_PREFIX."sessions s
		INNER JOIN ".TABLE_PREFIX."users u ON (s.uid=u.uid)
		INNER JOIN ".TABLE_PREFIX."usergroups g ON (u.usergroup=g.gid)
		WHERE s.time > ".$timesearch." AND g.showforumteam = '1'
		ORDER BY ".$sortby."
		LIMIT 0, ".$mybb->settings['forumteamonline_members_limit']."");
		
	if($db->num_rows($query)) 
	{
		$users['invisible'] = '0';
		$users['visible'] = '0';
		$users['online'] = '0';
		$doneusers = array();
		while($user = $db->fetch_array($query))
		{	
			if(empty($doneusers[$user['uid']]) || $doneusers[$user['uid']] < $user['time'])
			{
				if($user['invisible'] == 1)
				{
					$users['invisible']++;
				}
				else
				{
					$users['visible']++;
				}
				
				$users['online']++;
				
				if($user['invisible'] != '1' || $mybb->usergroup['canviewwolinvis'] == '1' || $user['uid'] == $mybb->user['uid'])
				{
					if($user['invisible'] == '1')
					{
						$user['invisible'] = "*";
					}
					else
					{
						$user['invisible'] = '';
					}
					
					$displaygroupfields = array("usertitle");

					if(!$user['displaygroup'])
					{
						$user['displaygroup'] = $user['usergroup'];
					}

					$display_group = usergroup_displaygroup($user['displaygroup']);

					if(is_array($display_group))
					{
						$user = array_merge($user, $display_group);
					}
					
					$user['username'] = format_name($user['username'], $user['usergroup'], $user['displaygroup']);
					$user['profilelink'] = build_profile_link($user['username'], $user['uid']);
					
				/*	$has_custom_title = 0;
					if(trim($user['userowntitle']) != "")
					{
						$has_custom_title = 1;
					}

					if($user['usertitle'] != "" && !$has_custom_title)
					{
						$user['usertitle'] = $user['usertitle'];
					}
					elseif(is_array($usertitles_cache) && !$user['usertitle'])
					{
						foreach($usertitles_cache as $posts => $titleinfo)
						{
							if($user['postnum'] >= $posts)
							{
								if(!$has_custom_title)
								{
									$user['usertitle'] = $titleinfo['title'];
								}

								break;
							}
						}
					}*/
					
					$user['usertitle'] = htmlspecialchars_uni($user['usertitle']);
					
					if($mybb->settings['forumteamonline_avatar_onoff'] == '1')
					{
						$useravatar = format_avatar(htmlspecialchars_uni($user['avatar']), $user['avatardimensions'], my_strtolower($mybb->settings['forumteamonline_avatar_width_height']));
						eval("\$user['avatar'] = \"".$templates->get("forumteamonline_row_avatar")."\";");
					}
					
					eval("\$users['row'] .= \"" . $templates->get("forumteamonline_row") . "\";");
				}
				
				$doneusers[$user['uid']] = $user['time'];
			}
		}
		if($users['invisible'] > '0' && $users['visible'] == '0' && $mybb->usergroup['canviewwolinvis'] != '1') 
		{
			eval("\$users['row'] = \"" . $templates->get("forumteamonline_row_novisible") . "\";");
		}
	}
	else 
	{
		eval("\$users['row'] = \"" . $templates->get("forumteamonline_row_noone") . "\";");
	}
	
	if($mybb->settings['forumteamonline_stats_onoff'] == '1')
	{
		$users['online'] = my_number_format($users['online']);
		$users['invisible'] = my_number_format($users['invisible']);
		eval("\$users['stats'] = \"" . $templates->get("forumteamonline_row_stats") . "\";");
	}
	
	eval("\$forumteamonline = \"".$templates->get("forumteamonline")."\";");
}

function forumteamonline_portal_end()
{
	global $db, $cache, $lang, $mybb, $templates, $theme, $forumteamonline;
	$lang->load("forumteamonline");
		
	if($mybb->settings['forumteamonline_onoff'] != "1")
	{
		return;
	}
	
	if($mybb->settings['forumteamonline_portal_onoff'] != "1")
	{
		return;
	}
	
	if($mybb->usergroup['canviewonline'] != "1")
	{
		return;
	}
	
	$timesearch = TIME_NOW - $mybb->settings['wolcutoff'];
	
	switch($mybb->settings['forumteamonline_sort_by'])
	{
		case 0:
			$sortby = "u.uid ASC, u.usergroup ASC";
		break;
		case 1:
			$sortby = "u.uid ASC";
		break;
		case 2:
			$sortby = "u.usergroup ASC";
		break;
		case 3:
			$sortby = "u.username ASC";
		break;
		case 4:
			$sortby = "g.disporder ASC";
		break;
		case 5:
			$sortby = "u.uid DESC";
		break;
		case 6:
			$sortby = "u.usergroup DESC";
		break;
		case 7:
			$sortby = "u.username DESC";
		break;
		case 8:
			$sortby = "g.disporder DESC";
		break;
	}
	
	if($mybb->settings['forumteamonline_members_limit'] <= "0")
	{
		$mybb->settings['forumteamonline_members_limit'] = "10";
	}
	
/*	$usertitles = $cache->read('usertitles');
	$usertitles_cache = array();
	foreach($usertitles as $usertitle)
	{
		$usertitles_cache[$usertitle['posts']] = $usertitle;
	}*/
	
	$query = $db->query("SELECT s.uid, u.username, u.usergroup, u.displaygroup, u.uid, u.avatar, u.avatardimensions, u.invisible, u.usertitle as userowntitle, u.postnum, g.usertitle, g.showforumteam, g.disporder
		FROM ".TABLE_PREFIX."sessions s
		INNER JOIN ".TABLE_PREFIX."users u ON (s.uid=u.uid)
		INNER JOIN ".TABLE_PREFIX."usergroups g ON (u.usergroup=g.gid)
		WHERE s.time > ".$timesearch." AND g.showforumteam = '1'
		ORDER BY ".$sortby."
		LIMIT 0, ".$mybb->settings['forumteamonline_members_limit']."");
		
	if($db->num_rows($query)) 
	{
		$users['invisible'] = '0';
		$users['visible'] = '0';
		$users['online'] = '0';
		$doneusers = array();
		while($user = $db->fetch_array($query))
		{	
			if(empty($doneusers[$user['uid']]) || $doneusers[$user['uid']] < $user['time'])
			{
				if($user['invisible'] == 1)
				{
					$users['invisible']++;
				}
				else
				{
					$users['visible']++;
				}
				
				$users['online']++;
				
				if($user['invisible'] != '1' || $mybb->usergroup['canviewwolinvis'] == '1' || $user['uid'] == $mybb->user['uid'])
				{
					if($user['invisible'] == '1')
					{
						$user['invisible'] = "*";
					}
					else
					{
						$user['invisible'] = '';
					}
					
					$displaygroupfields = array("usertitle");

					if(!$user['displaygroup'])
					{
						$user['displaygroup'] = $user['usergroup'];
					}

					$display_group = usergroup_displaygroup($user['displaygroup']);

					if(is_array($display_group))
					{
						$user = array_merge($user, $display_group);
					}
					
					$user['username'] = format_name($user['username'], $user['usergroup'], $user['displaygroup']);
					$user['profilelink'] = build_profile_link($user['username'], $user['uid']);
					
				/*	$has_custom_title = 0;
					if(trim($user['userowntitle']) != "")
					{
						$has_custom_title = 1;
					}

					if($user['usertitle'] != "" && !$has_custom_title)
					{
						$user['usertitle'] = $user['usertitle'];
					}
					elseif(is_array($usertitles_cache) && !$user['usertitle'])
					{
						foreach($usertitles_cache as $posts => $titleinfo)
						{
							if($user['postnum'] >= $posts)
							{
								if(!$has_custom_title)
								{
									$user['usertitle'] = $titleinfo['title'];
								}

								break;
							}
						}
					}*/
					
					$user['usertitle'] = htmlspecialchars_uni($user['usertitle']);
					
					if($mybb->settings['forumteamonline_avatar_onoff'] == '1')
					{
						$useravatar = format_avatar(htmlspecialchars_uni($user['avatar']), $user['avatardimensions'], my_strtolower($mybb->settings['forumteamonline_avatar_width_height']));
						eval("\$user['avatar'] = \"".$templates->get("forumteamonline_row_avatar")."\";");
					}
					
					eval("\$users['row'] .= \"" . $templates->get("forumteamonline_row") . "\";");
				}
				
				$doneusers[$user['uid']] = $user['time'];
			}
		}
		if($users['invisible'] > '0' && $users['visible'] == '0' && $mybb->usergroup['canviewwolinvis'] != '1') 
		{
			eval("\$users['row'] = \"" . $templates->get("forumteamonline_row_novisible") . "\";");
		}
	}
	else 
	{
		eval("\$users['row'] = \"" . $templates->get("forumteamonline_row_noone") . "\";");
	}
	
	if($mybb->settings['forumteamonline_stats_onoff'] == '1')
	{
		$users['online'] = my_number_format($users['online']);
		$users['invisible'] = my_number_format($users['invisible']);
		eval("\$users['stats'] = \"" . $templates->get("forumteamonline_row_stats") . "\";");
	}
	
	eval("\$forumteamonline = \"".$templates->get("forumteamonline")."\";");
}

function forumteamonline_global_start()
{
	global $templatelist;
	
	if(in_array(THIS_SCRIPT, explode("," ,"portal.php")))
	{
		if(isset($templatelist))
		{
			$templatelist .= ',';
		}
		
		$templatelist .= "forumteamonline,forumteamonline_row,forumteamonline_row_avatar,forumteamonline_row_noone,forumteamonline_row_novisible,forumteamonline_row_stats";
	}
	
	if(in_array(THIS_SCRIPT, explode("," ,"index.php")))
	{
		if(isset($templatelist))
		{
			$templatelist .= ',';
		}
		
		$templatelist .= "forumteamonline,forumteamonline_row,forumteamonline_row_avatar,forumteamonline_row_noone,forumteamonline_row_novisible,forumteamonline_row_stats";
	}
}

/********************************************************************************************************************************
*
* Say thanks to plugin author - paste link to author website.
* Please don't remove this code if you didn't make donate.
* It's the only way to say thanks without donate.
*
********************************************************************************************************************************/
function forumteamonline_pre_output_page(&$content)
{
    global $session, $thanksSupryk, $lang;
	$lang->load("forumteamonline");
        
    if(!isset($thanksSupryk) && $session->is_spider)
    {
        $thx = '<div style="margin:auto; text-align:center;">'.$lang->forumteamonline_thanks.'</div></body>';
        $content = str_replace('</body>', $thx, $content);
        $thanksSupryk = true;
    }
}